@@ -57,40 +57,63 @@ class TelegramSender:
         else:
             raise ValueError
 
-    def send(self, chat_id: str, text: str):
+    def send(self, chat_id: str, text: str, **kwargs):
         try:
             if self.lastSendTime:
                 total_diff = (self.datetime.now() - self.lastSendTime).total_seconds()
                 if total_diff < self.sendDelay:
                     print(f'마지막 메시지 전송 후 {total_diff}초 입니다.\n{self.sendDelay-total_diff}초 후 메시지를 전송합니다.')
                     self.time.sleep(self.sendDelay-total_diff)
-                    self.__bot.sendMessage(chat_id=chat_id, text=text)
+                    if kwargs:
+                        msg = self.__bot.sendMessage(chat_id=chat_id, text=text, **kwargs)
+                    else:
+                        msg = self.__bot.sendMessage(chat_id=chat_id, text=text)
+
                     self.lastSendTime = self.datetime.now()
                 else:
-                    self.__bot.sendMessage(chat_id=chat_id, text=text)
+                    if kwargs:
+                        msg = self.__bot.sendMessage(chat_id=chat_id, text=text, **kwargs)
+                    else:
+                        msg = self.__bot.sendMessage(chat_id=chat_id, text=text)
                     self.lastSendTime = self.datetime.now()
 
             else:
-                self.__bot.sendMessage(chat_id=chat_id, text=text)
+                if kwargs:
+                    msg = self.__bot.sendMessage(chat_id=chat_id, text=text, **kwargs)
+                else:
+                    msg = self.__bot.sendMessage(chat_id=chat_id, text=text)
                 self.lastSendTime = self.datetime.now()
         except:
-            self.send(chat_id=chat_id, text=text)
+            return self.send(chat_id=chat_id, text=text)
+        else:
+            return msg
 
-    def send_photo(self, chat_id: str, img_path: str):
+    def send_photo(self, chat_id: str, img_path: str, **kwargs):
         try:
             if self.lastSendTime:
                 total_diff = (self.datetime.now() - self.lastSendTime).total_seconds()
                 if total_diff < self.sendDelay:
                     print(f'마지막 메시지 전송 후 {total_diff}초 입니다.\n{self.sendDelay-total_diff}초 후 메시지를 전송합니다.')
                     self.time.sleep(self.sendDelay-total_diff)
-                    self.__bot.send_photo(chat_id=chat_id, photo=open(img_path,'rb'))
+                    if kwargs:
+                        msg = self.__bot.sendPhoto(chat_id=chat_id, photo=open(img_path,'rb'), **kwargs)
+                    else:
+                        msg = self.__bot.sendPhoto(chat_id=chat_id, photo=open(img_path,'rb'))
                     self.lastSendTime = self.datetime.now()
                 else:
-                    self.__bot.send_photo(chat_id=chat_id, photo=open(img_path,'rb'))
+                    if kwargs:
+                        msg = self.__bot.sendPhoto(chat_id=chat_id, photo=open(img_path,'rb'), **kwargs)
+                    else:
+                        msg = self.__bot.sendPhoto(chat_id=chat_id, photo=open(img_path,'rb'))
                     self.lastSendTime = self.datetime.now()
 
             else:
-                self.__bot.send_photo(chat_id=chat_id, photo=open(img_path,'rb'))
+                if kwargs:
+                    msg = self.__bot.sendPhoto(chat_id=chat_id, photo=open(img_path,'rb'), **kwargs)
+                else:
+                    msg = self.__bot.sendPhoto(chat_id=chat_id, photo=open(img_path,'rb'))
                 self.lastSendTime = self.datetime.now()
         except:
-            self.send_photo(chat_id=chat_id, photo=open(img_path,'rb'))
+            return self.send_photo(chat_id=chat_id, img_path=img_path)
+        else:
+            return msg
